@@ -40,7 +40,11 @@ def signout(request):
         _cont = '/'
     request.registry.notify(events.SignOut(request))
     headers = forget(request)
-    return HTTPFound(_cont, headers=headers)
+    redirect_url = pvo.VGID_SIGNOUT_URL + '?' + urlencode({
+        'client_id': pvo.CLIENT_ID,
+        '_cont': _cont,
+    })
+    return HTTPFound(redirect_url, headers=headers)
 
 
 @subscriber(events.SignIn)
